@@ -118,6 +118,7 @@ void PolicyKitListener::initiateAuthentication(const QString &actionId,
 
     connect(m_dialog.data(), SIGNAL(okClicked()), SLOT(dialogAccepted()));
     connect(m_dialog.data(), SIGNAL(rejected()), SLOT(dialogCanceled()));
+    connect(m_dialog.data(), SIGNAL(userSelected()), SLOT(userSelected()));
 
     m_dialog->show();
 
@@ -230,8 +231,10 @@ void PolicyKitListener::cancelAuthentication()
 
 void PolicyKitListener::request(const QString &request, bool echo)
 {
-    Q_UNUSED(echo);
-    qDebug() << "Request: " << request;
+    qDebug() << "Request: " << request << " echo: " << echo;
+    if (!m_dialog.isNull()) {
+        m_dialog.data()->request(request, echo);
+    }
 }
 
 void PolicyKitListener::completed(bool gainedAuthorization)
@@ -280,9 +283,9 @@ void PolicyKitListener::dialogCanceled()
     finishObtainPrivilege();
 }
 
-void PolicyKitListener::userSelected(const PolkitQt1::Identity &identity)
+void PolicyKitListener::userSelected()
 {
-    m_selectedUser = identity;
+    m_selectedUser = m_dialog.data()->adminUserSelected();
     // If some user is selected we must destroy existing session
     if (!m_session.isNull()) {
         m_session.data()->deleteLater();
